sign_crn: SageMath package for (chemical) reaction networks using sign vector conditions
========================================================================================

Description
-----------

SageMath package for (chemical) reaction networks using sign vector conditions

License
-------

GPL-3.0-or-later

Upstream Contact
----------------

https://pypi.org/project/sign-crn/

